%% this plots CoSMO dynamics of Model i and ii, and compares growth rates from simulations and calculations.
close all;
clear all;
global gL gA dL dA cA cL rA rL KL KA nL nA
LordRam
%L-A+ parameters
gL =0.51 ; %% max birth of L-A+ (/hr)
KL = 2.1;    %% Monod constant of L-A+ (uM)
nL=3.2; %% birth cooperativity
dL = 0.06;  %% death rate of L-A+ (/hr)
cL = 3.8;    %% lysine consumption per new cell (fmole/cell) 
rA = 0.06;   %% Model i; 3 fmole ade released per dead cell multiplied with death rate is equivalent to ade release rate(fmole/cell/hr)
 % A-L+ parameters
gA =0.46 ; %% max birth of A-L+ (/hr)
KA = 0.68;   %% Monod constant of A-L+ (uM)
nA=1.12; %% birth cooperativity
dA =0.005 ;  %%  death rate of A-L+ (/hr)
cA = 0.96;    %% ade consumption per new cell (fmole/cell)
rL=0.15;   %% Model i; 15 fmole lys released per dead cell multiplied with death rate is equivalent to lys release rate (fmole/cell/hr)



%%%Sam's experiment 20150922

shour=[0.00	5.83	22.67	29.50	46.50	53.50 74.50]; % time (hr)
sred=[1.75E+06	2.83E+06	4.95E+06	1.60E+07	3.03E+08	4.38E+08	1.69E+09
    1.75E+06	2.85E+06	4.88E+06	2.13E+07	2.85E+08	3.69E+08	1.19E+09
1.75E+06	2.80E+06	4.72E+06	2.06E+07	2.90E+08	3.76E+08 1.55E+09]; %Live L-A+ density (/ml), one experiment/row

sgreen=[1.75E+06	1.81E+06	9.88E+06	8.89E+06	2.47E+07	2.78E+08	1.94E+09
1.75E+06	1.80E+06	5.63E+06	5.95E+06	4.80E+07	3.54E+08	1.27E+09
1.75E+06	1.86E+06	5.07E+06	5.69E+06	4.84E+07	3.61E+08 1.73E+09]; %Live A-L+ density (/ml), one experiment/row

stotal=[3.50E+06	4.66E+06	1.50E+07	2.51E+07	3.28E+08	7.19E+08	3.64E+09
3.50E+06	4.70E+06	9.86E+06	2.64E+07	3.39E+08	7.41E+08	3.30E+09
3.50E+06	4.67E+06	1.06E+07	2.74E+07	3.34E+08	7.26E+08	2.47E+09]; %total Live density (/ml), one experiment/row

tsstep=0.5; % time step for evaluating ODE solution
tspan=0:tsstep:80;% duration for evaluating ODE solution
c0=[1.75E+06/1000000;1.75E+06/1000000;0;0];% initial condition
[t x]=ode23s(@cosmofunc,tspan, c0);


ana1=-(dA+dL)/2+sqrt(rL*rA/cL/cA+(dA-dL)^2/4);  % analytical, Eq. 15
disp('Analytical')
disp(ana1)

%calculating doubling time from simulated dynamics starting at ti.
ti=70;
dt=2;
tf=ti+dt;
td1=log(2)*dt/log((x(tf/tsstep,1)+x(tf/tsstep,2))/(x(ti/tsstep,1)+x(ti/tsstep,2)));
gr1=log(2)/td1;
disp('doubling time(hrs)')
disp(td1)
disp('growth rate')
disp(gr1)

% this plots expt/simulation comparison (Fig 1C)
marksize=9;
figure (1)
plot(t, x(:,1), 'm:')
hold on
plot(t, x(:,2), ':','color', [0 0.75 0])
plot(t, x(:,1)+x(:,2), 'k:')
e1=errorbar(shour, mean(sred, 1)/1000000,2*std(sred, 1)/1000000,'ms-'); 
e2=errorbar(shour, mean(sgreen, 1)/1000000,2*std(sgreen, 1)/1000000,'s-', 'color', [0 0.5 0]); 
e3=errorbar(shour, mean(stotal, 1)/1000000,2*std(stotal, 1)/1000000,'ks-'); 


rA = 0.26;   %% Mdel ii; RM11 release rate in starved monoculture
rL=0.52;   %% Mdel ii; RM11 release rate in starved monoculture
tsstep=0.5; % time step for evaluating ODE solution
tspan=0:tsstep:80;% duration for evaluating ODE solution
c0=[1.75E+06/1000000;1.75E+06/1000000;0;0];% initial condition
[t x]=ode23s(@cosmofunc,tspan, c0);

ana2=-(dA+dL)/2+sqrt(rL*rA/cL/cA+(dA-dL)^2/4);  % analytical solution; 
disp('Analytical')
disp(ana2)

%calculating doubling time
ti=70;
dt=2;
tf=ti+dt;
td2=log(2)*dt/log((x(tf/tsstep,1)+x(tf/tsstep,2))/(x(ti/tsstep,1)+x(ti/tsstep,2)));
gr2=log(2)/td2;
disp('doubling time(hrs)')
disp(td2)
disp('growth rate')
disp(gr2)

plot(t, x(:,1), 'm:')
hold on
plot(t, x(:,2), ':','color', [0 0.75 0])
plot(t, x(:,1)+x(:,2), 'k:')
e1=errorbar(shour, mean(sred, 1)/1000000,2*std(sred, 1)/1000000,'ms-'); 
e2=errorbar(shour, mean(sgreen, 1)/1000000,2*std(sgreen, 1)/1000000,'s-', 'color', [0 0.5 0]); 
e3=errorbar(shour, mean(stotal, 1)/1000000,2*std(stotal, 1)/1000000,'ks-'); 
hold off
xlim([0 80])
ylim([1 2E6])
xlabel('hours')
ylabel('cell density (millions/ml)')
set(gca, 'yscale', 'log','ticklength', [0.03 0.05], 'ytick', [1 10 1E2 1E3 1E4 1E5 1E6]) 
set(e1, 'MarkerSize', marksize)
set(e2, 'MarkerSize', marksize)
set(e3, 'MarkerSize', marksize)


%% this plots Fig1-FS1
figure(2)
bar([1 2 3],[0.11 gr2 ana2])
hold on
errorbar(1, 0.11, 0.01)
% the above plots exp, Ade parameters simulation and Ade parameters
% calculation


 % **Hyp** parameters
gA =0.44 ; %% max birth of A-L+ (/hr)
KA = 1.3;   %% Monod constant of A-L+ (uM)
nA=1.5; %% birth cooperativity
tsstep=0.5; % time step for evaluating ODE solution
tspan=0:tsstep:80;% duration for evaluating ODE solution
c0=[1.75E+06/1000000;1.75E+06/1000000;0;0];% initial condition
[t x]=ode23s(@cosmofunc,tspan, c0);

anaH=-(dA+dL)/2+sqrt(rL*rA/cL/cA+((dA-dL)^2/4))  % analytical solution;


%calculating doubling time
ti=70;
dt=2;
tf=ti+dt;
tdH=log(2)*dt/log((x(tf/tsstep,1)+x(tf/tsstep,2))/(x(ti/tsstep,1)+x(ti/tsstep,2)));
grH=log(2)/tdH
bar([4 5],[grH anaH])
hold off
set(gca, 'ticklength', [0.025 0.05]) 
ylabel('CoSMO post-lag growth rate (/hr)')

